
// AutoItX3.java
// Andrew Davison, ad@fivedots.coe.psu.ac.th, March 2014

/* A JNA Wrapper (https://jna.dev.java.net/) around the AutoItX DLL 
   (AutoItX3.dll), available as part of AutoIt v3.3.10.2 from 
   http://www.autoitscript.com/site/autoit/

   Using JNA v.4.1.0 (https://github.com/twall/jna).
   Docs at: http://twall.github.io/jna/4.1.0/

   This file was partially generated with JNAerator
   (http://jnaerator.googlecode.com/), a tool written by Olivier Chafik.

   It is also based on autoitx.java from the JWinAuto download
   (http://sourceforge.net/projects/jwinauto/) by
   Alan Richardson (2007) (user: ajr_compdev), which uses the same approach,
   but with an earlier version of AutoIt and JNA.


   The AutoIt functions are described most detail at:
     http://www.autoitscript.com/autoit3/docs/functions.htm
   but this documentation includes non-AutoItX DLL functions, such as math functions.

   A more focussed explanation are the Help files included in the AutoIt download:
     C:\Program Files\AutoIt3\AutoItX\AutoItX.chm  
     (in the "COM Interface" section!!
   and
     C:\Program Files\AutoIt3\AutoIt.chm

   Lots of advice on using the functions can be found at 
   the AutoIt scripting forum: 
     http://www.autoitscript.com/forum/

   Information on Window handles, title captions, etc can be 
   found using AutoIt WindowInfo (Au3Info.exe or Au3Info_x64.exe)
   which is a tool in the AutoIt download. I also used WinSpy++
   (http://www.catch22.net/software/winspy-17).

   ----
   UseToolTip.java contains an example of how to call the tootip function directly,
   and this approach can be used with all the functions here. However,
   the usual idea is to use AutoItX3 via the methods in Jau.java.

*/

import java.util.*;

import com.sun.jna.*;
import com.sun.jna.win32.*;
import com.sun.jna.platform.win32.*;
import com.sun.jna.platform.win32.WinDef.*;



public interface AutoItX3 extends com.sun.jna.Library
{

  public static final int AU3_INTDEFAULT = -2147483647;
       // used by some functions as a default int parameter (largest negative number)
       // this is -(2^31-1), whereas Java's Integer.MIN_VALUE is -2^31 (one smaller)



  // link to the AutoIt DLL (32 or 64 bit version) via JNA
  public AutoItX3 INSTANCE =  (AutoItX3) Native.loadLibrary(
                                     Jau.getAutoItDLL(), 
                                     AutoItX3.class, W32APIOptions.DEFAULT_OPTIONS);


  public void AU3_Init();

  public int AU3_error();

  public int AU3_AutoItSetOption(String option, int val);

  public void AU3_ClipGet(char[] clip, int bufSize);

  public int AU3_ClipPut(String clip);

  public int AU3_ControlClick(String title, String txt, String ctrl, 
                   String buttonLabel, int numClicks, int x, int y);

  public int AU3_ControlClickByHandle(HWND hWnd, HWND hCtrl, String szButton, 
                    int numClicks, int x, int y);

  public void AU3_ControlCommand(String title, String txt, String ctrl, 
                             String cmd, String szExtra, char[] result, int bufSize);

  public void AU3_ControlCommandByHandle(HWND hWnd, HWND hCtrl, String cmd, 
                             String szExtra, char[] result, int bufSize);

  public void AU3_ControlListView(String title, String txt, String ctrl, 
                     String cmd, String szExtra1, String szExtra2, char[] result, int bufSize);

  public void AU3_ControlListViewByHandle(HWND hWnd, HWND hCtrl, String cmd, 
                      String szExtra1, String szExtra2, char[] result, int bufSize);

  public int AU3_ControlDisable(String title, String txt, String ctrl);
  // "grays out" a control

  public int AU3_ControlDisableByHandle(HWND hWnd, HWND hCtrl);

  public int AU3_ControlEnable(String title, String txt, String ctrl);

  public int AU3_ControlEnableByHandle(HWND hWnd, HWND hCtrl);

  public int AU3_ControlFocus(String title, String txt, String ctrl);
  // sets input focus to a given control on a window

  public int AU3_ControlFocusByHandle(HWND hWnd, HWND hCtrl);

  public void AU3_ControlGetFocus(String title, String txt, 
                                             char[] controlWithFocus, int bufSize);

  public void AU3_ControlGetFocusByHandle(HWND hWnd, char[] controlWithFocus, int bufSize);

  public HWND AU3_ControlGetHandle(HWND hWnd, String ctrl);

  public void AU3_ControlGetHandleAsText(String title, String txt, String ctrl, 
                                                    char[] handle, int bufSize);

  public int AU3_ControlGetPos(String title, String txt, String ctrl, RECT rect);

  public int AU3_ControlGetPosByHandle(HWND hWnd, HWND hCtrl, RECT rect);

  public void AU3_ControlGetText(String title, String txt, String ctrl, 
                                                     char[] controlText, int bufSize);

  public void AU3_ControlGetTextByHandle(HWND hWnd, HWND hCtrl, 
                                                     char[] controlText, int bufSize);

  public int AU3_ControlHide(String title, String txt, String ctrl);

  public int AU3_ControlHideByHandle(HWND hWnd, HWND hCtrl);

  public int AU3_ControlMove(String title, String txt, String ctrl, 
                                                int x, int y, int width, int height);

  public int AU3_ControlMoveByHandle(HWND hWnd, HWND hCtrl, 
                                                int x, int y, int width, int height);


  public int AU3_ControlSend(String title, String txt, String ctrl, 
                                                   String sendText, int nMode);

  public int AU3_ControlSendByHandle(HWND hWnd, HWND hCtrl, String sendText, int nMode);


  public int AU3_ControlSetText(String title, String txt, String ctrl, String controlText);

  public int AU3_ControlSetTextByHandle(HWND hWnd, HWND hCtrl, String controlText);

  public int AU3_ControlShow(String title, String txt, String ctrl);

  public int AU3_ControlShowByHandle(HWND hWnd, HWND hCtrl);

  public void AU3_ControlTreeView(String title, String txt, String ctrl, String cmd, 
                     String szExtra1, String szExtra2, char[] result, int bufSize);

  public void AU3_ControlTreeViewByHandle(HWND hWnd, HWND hCtrl, String cmd, 
                     String szExtra1, String szExtra2, char[] result, int bufSize);


  public void AU3_DriveMapAdd(String device, String szShare, int nFlags, String user, 
                     String pwd, char[] result, int bufSize);

  public int AU3_DriveMapDel(String device);

  public void AU3_DriveMapGet(String device, char[] szMapping, int bufSize);

  public int AU3_IsAdmin();

  public int AU3_MouseClick(String szButton, int x, int y, int numClicks, int speed);

  public int AU3_MouseClickDrag(String szButton, int x1, int y1, int x2, int y2, int speed);

  public int AU3_MouseDown(String szButton);

  public int AU3_MouseGetCursor();

  public void AU3_MouseGetPos(WinDef.POINT point);

  public int AU3_MouseMove(int x, int y, int speed);

  public int AU3_MouseUp(String szButton);

  public int AU3_MouseWheel(String szDirection, int numClicks);

  public int AU3_Opt(String option, int val);

  public int AU3_PixelChecksum(RECT rect, int nStep);
  // Generates a checksum for a region of pixels

  public int AU3_PixelGetColor(int x, int y);
  // Returns a pixel color according to x,y coordinates

  public void AU3_PixelSearch(RECT rect, int nCol, int nVar, int nStep, WinDef.POINT point);


  public int AU3_ProcessClose(String process);

  public int AU3_ProcessExists(String process);

  public int AU3_ProcessSetPriority(String process, int nPriority);

  public int AU3_ProcessWait(String process, int timeOut);

  public int AU3_ProcessWaitClose(String process, int timeOut);


  public int AU3_Run(String program, String szDir, int nShowFlag);
  
  public int AU3_RunWait(String program, String szDir, int nShowFlag);
  

  public int AU3_RunAs(String user, String szDomain, String password, 
                            int nLogonFlag, String program, String szDir, int nShowFlag);

  public int AU3_RunAsWait(String user, String szDomain, String password, 
                           int nLogonFlag, String program, String szDir, int nShowFlag);

  public void AU3_Send(String sendText, int nMode);

  public int AU3_Shutdown(int nFlags);

  public void AU3_Sleep(int nMilliseconds);

  public int AU3_StatusbarGetText(String title, String txt, int nPart, 
                                                    char[] statusText, int bufSize);

  public int AU3_StatusbarGetTextByHandle(HWND hWnd, int nPart, 
                                                    char[] statusText, int bufSize);

  public int AU3_ToolTip(String tip, int x, int y);

  public int AU3_WinActivate(String title, String txt);

  public int AU3_WinActivateByHandle(HWND hWnd);

  public int AU3_WinActive(String title, String txt);

  public int AU3_WinActiveByHandle(HWND hWnd);

  public int AU3_WinClose(String title, String txt);

  public int AU3_WinCloseByHandle(HWND hWnd);

  public int AU3_WinExists(String title, String txt);

  public int AU3_WinExistsByHandle(HWND hWnd);

  public int AU3_WinGetCaretPos(WinDef.POINT point);

  public void AU3_WinGetClassList(String title, String txt, char[] classes, int bufSize);

  public void AU3_WinGetClassListByHandle(HWND hWnd, char[] classes, int bufSize);

  public int AU3_WinGetClientSize(String title, String txt, RECT rect);

  public int AU3_WinGetClientSizeByHandle(HWND hWnd, RECT rect);

  public HWND AU3_WinGetHandle(String title, String txt);

  public void AU3_WinGetHandleAsText(String title, String txt, char[] handle, int bufSize);

  public int AU3_WinGetPos(String title, String txt, RECT rect);

  public int AU3_WinGetPosByHandle(HWND hWnd, RECT rect);

  public int AU3_WinGetProcess(String title, String txt);

  public int AU3_WinGetProcessByHandle(HWND hWnd);

  public int AU3_WinGetState(String title, String txt);

  public int AU3_WinGetStateByHandle(HWND hWnd);

  public void AU3_WinGetText(String title, String txt, char[] retText, int bufSize);
  // retrieves the text from a window

  public void AU3_WinGetTextByHandle(HWND hWnd, char[] retText, int bufSize);

  public void AU3_WinGetTitle(String title, String txt, char[] winTitle, int bufSize);

  public void AU3_WinGetTitleByHandle(HWND hWnd, char[] title, int bufSize);

  public int AU3_WinKill(String title, String txt);

  public int AU3_WinKillByHandle(HWND hWnd);

  public int AU3_WinMenuSelectItem(String title, String txt, 
                                String item1, String item2, String item3, String item4, 
                                String item5, String item6, String item7, String item8);

  public int AU3_WinMenuSelectItemByHandle(HWND hWnd, 
                                String item1, String item2, String item3, String item4, 
                                String item5, String item6, String item7, String item8);

  public void AU3_WinMinimizeAll();

  public void AU3_WinMinimizeAllUndo();

  public int AU3_WinMove(String title, String txt, int x, int y, int width, int height);

  public int AU3_WinMoveByHandle(HWND hWnd, int x, int y, int width, int height);

  public int AU3_WinSetOnTop(String title, String txt, int nFlag);

  public int AU3_WinSetOnTopByHandle(HWND hWnd, int nFlag);

  public int AU3_WinSetState(String title, String txt, int nFlags);

  public int AU3_WinSetStateByHandle(HWND hWnd, int nFlags);

  public int AU3_WinSetTitle(String title, String txt, String szNewTitle);

  public int AU3_WinSetTitleByHandle(HWND hWnd, String szNewTitle);

  public int AU3_WinSetTrans(String title, String txt, int nTrans);

  public int AU3_WinSetTransByHandle(HWND hWnd, int nTrans);

  public int AU3_WinWait(String title, String txt, int timeOut);

  public int AU3_WinWaitByHandle(HWND hWnd, int timeOut);

  public int AU3_WinWaitActive(String title, String txt, int timeOut);

  public int AU3_WinWaitActiveByHandle(HWND hWnd, int timeOut);

  public int AU3_WinWaitClose(String title, String txt, int timeOut);

  public int AU3_WinWaitCloseByHandle(HWND hWnd, int timeOut);

  public int AU3_WinWaitNotActive(String title, String txt, int timeOut);

  public int AU3_WinWaitNotActiveByHandle(HWND hWnd, int timeOut);

}  // end of AutoItX3 class
