
// TestDesktop.java
// Andrew Davison, ad@fivedots.coe.psu.ac.th, April 2014

/* Tests of Jau methods related to the desktop, the mouse cursor,
   and all the windows on the screen
*/


import java.util.*;
import com.sun.jna.platform.win32.WinDef.*;


public class TestDesktop
{

  public static void main (String args[])
  {

    HWND desktopHwnd = Jau.winGetDesktop();
    System.out.println("Desktop handle: " + Jau.handleString(desktopHwnd));

    System.out.println("Desktop controls (i.e. parts on the desktop)");
    List<Integer> ctrlIDs = Jau.controlIDsList(desktopHwnd);
    for (Integer ctrlID : ctrlIDs) {
       System.out.println("  ID: " + ctrlID +
                              " -- " + Jau.controlGetClassName(desktopHwnd, ctrlID) +
                              " -- \"" + Jau.controlGetText(desktopHwnd, ctrlID) + "\"");
    }
    System.out.println();

    // access control ID 1 of the desktop == the SysListView32 control
    HWND ctrlHandle = Jau.controlGetHandle(desktopHwnd, 1);
    System.out.println("Control handle for ID 1: " + Jau.handleString(ctrlHandle));
    System.out.println("Control ID from handle: " + Jau.controlIDFromHandle(ctrlHandle));
    System.out.println();

    printListTitles("Desktop", desktopHwnd, 1);   // 1 == the SysListView32 control ID


    System.out.println("\n------------------ mouse tests --------------------------");
    moveMouse();

    HWND mouseHwnd = Jau.mouseWindowHandle();
    System.out.println("Mouse Handle: " + Jau.handleString(mouseHwnd));
    System.out.println("Cursor over window \"" + Jau.winGetApp(mouseHwnd) + "\"");


    System.out.println("\n------------------ windows tests --------------------------");
    System.out.println("**WARNING: about to minimize everything for a second...");
    Jau.sleep(1000);
    Jau.winMinimizeAll();
    Jau.sleep(1000);
    Jau.winMinimizeAllUndo();
    Jau.sleep(1000);
    System.out.println("... and unminimize");
    System.out.println();

    System.out.println("Apps currently running on desktop:");
    List<String> apps = Jau.winListApps();
    for(String app : apps)
      System.out.println("  " + app);

    System.out.println("Their handles:");
    List<HWND> handles = Jau.winListHandles();
    for(HWND hWnd : handles)
      System.out.println("  " + Jau.handleString(hWnd));

    System.out.println("Their titles:");
    List<String> titles = Jau.winListTitles();
    for(String title : titles)
      System.out.println("  \"" + title + "\"");

    System.out.println("-----------------------------\n");


    handles = Jau.winListHandles("notepad");
    if (handles.size() == 0)
      System.out.println("No running windows found");
    else {
      HWND hWnd = handles.get(0);
      Jau.winActivate(hWnd);
      System.out.println("Top window title: \"" + Jau.winGetTitle(hWnd) + "\"");
      System.out.println("Top window handle: " + Jau.handleString(hWnd));
      Jau.sleep(1000);

      // flash the window while it is minimized
      Jau.winMinimize(hWnd);
      Jau.winFlash(hWnd);
      Jau.sleep(4000);
      Jau.winRestore(hWnd);   // back to original size
      Jau.sleep(1000);
      System.out.println("  and now sending it to the back ==>");
      Jau.sleep(1000);
      Jau.winToBack(hWnd);    // but the window is still active 
    }
  }  // end of main()



  private static void printListTitles(String listTitle, HWND hWnd, int ctrlID)
  // print out list-view titles for the specified control
  {
    int numItems = Jau.toInt( Jau.controlListView(hWnd, ctrlID, "GetItemCount", "", "") );
    System.out.println(listTitle + ": number of items: " + numItems);
    for (int i=0; i < numItems; i++) {
      String title = Jau.controlListView(hWnd, ctrlID, "GetText", ""+i, "0");
      System.out.println((i+1) + ". \"" + title + "\"");
    }
  }  // end of printListTitles()



  private static void moveMouse()
  {
    System.out.println("Mouse manipulation...");
    java.awt.Point pos = Jau.mouseGetPos();
    reportMousePos(pos.x, pos.y);

    System.out.println("Move to 0,0, sloooooowly");
    Jau.mouseMoveTo(-100, 0, 100);
    reportMousePos(0, 0);
    Jau.sleep(500);

    System.out.println("Faster");
    Jau.mouseMoveTo(400, 200, 50);
    reportMousePos(400, 200);
    Jau.sleep(500);

    System.out.println("Default speed");
    Jau.mouseMoveTo(250, 450);
    reportMousePos(250, 450);
    Jau.sleep(500);

    System.out.println("Superfast");
    Jau.mouseMoveTo(1, 1, 1);
    reportMousePos(1, 1);
    Jau.sleep(2000);

    System.out.println("Set mouse back to where it started");
    Jau.mouseMoveTo(pos.x, pos.y, 0);
    reportMousePos(pos.x, pos.y);
    Jau.sleep(500);
    System.out.println();
  }  // end of moveMouse()



  private static void reportMousePos(int x, int y)
  {
    java.awt.Point pos = Jau.mouseGetPos();
    System.out.println("  Mouse at (" + pos.x + ", " + pos.y + ")");
  }  // end of reportMousePos()


}  // end of TestDesktop class
