
// TestWin.java
// Andrew Davison, ad@fivedots.coe.psu.ac.th, April 2014

/* Lots of tests of window-related methods. 
     e.g. testing the window state, size, position, visibility
          basic text reading and writing, minimizing
*/

import java.awt.*;
import com.sun.jna.platform.win32.WinDef.*;


public class TestWin
{
  public static void main (String args[])
  {
    HWND hWnd = Jau.run("notepad");
    System.out.println();

    System.out.println("Window title: " + Jau.winGetTitle(hWnd));
    System.out.println("Is a window? " + Jau.isWindow(hWnd));
    System.out.println("Is active? " + Jau.winActive(hWnd));
    System.out.println("Name of application: " + Jau.winGetApp(hWnd));
    System.out.println("Is it notepad? " + Jau.winIsApp(hWnd, "notepad"));
    System.out.println();

    System.out.println("Window area: " + Jau.winGetPos(hWnd));
    System.out.println("Client area: " + Jau.winGetClientSize(hWnd));
    System.out.println();

    System.out.println("Make window translucent for 2 secs...");
    Jau.winSetTrans(hWnd, 0.5);
    Jau.sleep(2000);
    Jau.winSetVisibility(hWnd, true);
    System.out.println();

    System.out.println("Moving the window about...");
    Jau.winMove(hWnd, 200, 200);
    Jau.sleep(1000);
    Jau.winMoveToRightEdge(hWnd);
    Jau.sleep(1000);
    Jau.winMoveToBottomEdge(hWnd);
    Jau.sleep(1000);
    System.out.println();

    System.out.println("Resize and center...");
    Jau.winResize(hWnd, 0.25);
    Jau.sleep(1000);
    Jau.winMoveToCenter(hWnd);
    Jau.sleep(1000);
    System.out.println();

    System.out.println("Minimize for a second...");
    Jau.winMinimize(hWnd);
    Jau.sleep(1000);
    Jau.winRestore(hWnd);
    Jau.sleep(1000);
    System.out.println();


    System.out.println("Writing/reading from the window...");
    System.out.println("  Initial Caret pos: " + pointAsCoord(Jau.winGetCaretPos()));

    Jau.send(hWnd, "hello world\n");
    System.out.println("  Caret pos after write: " + pointAsCoord(Jau.winGetCaretPos()));

    System.out.println("\nText read from window: \"" + Jau.winGetText(hWnd) + "\"");
    System.out.println("  Caret pos after read: " + pointAsCoord(Jau.winGetCaretPos()));
    System.out.println();

    if (hWnd != null) {
      Jau.sleep(2000);
      // Jau.winClose(hWnd);
      Jau.winKill(hWnd);     // use kill so save request is ignored
    }
  }  // end of main()


  private static String pointAsCoord(Point pos)
  {  return "(" + pos.x + ", " + pos.y + ")";  }

}  // end of TestWin class
