
// UseCalc.java
// Andrew Davison, ad@fivedots.coe.psu.ac.th, April 2014

/* Using the calculator's controls to do two calculations:
          23 + 20  via text sends to the calculator's text control
    and   5 * 7    via button presses

   Unlike in AutoIt, a control can only be manipulated via its
   control ID, which can be found using WinSpy++
   (http://www.catch22.net/software/winspy-17).

   Control IDs can be integers or hexadecimals.

   On my XP test machine, "calc" matches "Calculator Plus", which uses
   different control IDs than the basic Calculator!
*/


import com.sun.jna.platform.win32.WinDef.*;

public class UseCalc
{

  public static void main (String args[])
  {
    String vers = Jau.windowsVersion();
    System.out.println("Windows version: " + vers);

    HWND hWnd = Jau.run("calc");  
    System.out.println("Application being used: " + Jau.winGetApp(hWnd));
    String winTitle = Jau.winGetTitle(hWnd);
    System.out.println("Title: \"" + winTitle +"\"");

    int inCtrlID = 0x96;
         // 0x96 (integer 150) is the control ID for the calculator's input window
         // all the control IDs used here were obtained by applying WinSpy++ to the calculator
    if (winTitle.contains("Plus"))
      inCtrlID = 0x193;    // 0x193 on "Calculator Plus" on my XP test machine

    System.out.println("---------------------------------------");
    System.out.println("Adding 23 and 10");
        // this calculation uses controlSend() to 'write' text into the calculator's input window

    Jau.controlSend(hWnd, inCtrlID, "23");   

    Jau.sleep(1000);
    System.out.println("First input: " + Jau.controlGetText(hWnd, inCtrlID));

    System.out.println("send '+'");
    Jau.controlSend(hWnd, inCtrlID, "+", 1);  
             // use AutoIT's raw mode to send the "+"
             // see http://www.autoitscript.com/autoit3/docs/functions/Send.htm
    Jau.sleep(1000);

    int controlIDFocus = Jau.controlGetFocus(hWnd);
    System.out.println("Id of Control with current focus: " + controlIDFocus + "; hex: " +
                                                Jau.hexString(controlIDFocus));

    Jau.controlSend(hWnd, inCtrlID, "10");
    System.out.println("Second input: " + Jau.controlGetText(hWnd, inCtrlID));

    Jau.sleep(1000);

    System.out.println("send '='");
    Jau.controlSend(hWnd, inCtrlID, "=");
    Jau.sleep(1000);

    System.out.println("  Result: " + Jau.controlGetText(hWnd, inCtrlID));


    // the next calculation only works on the calculator in Windows 7!

    Jau.sleep(2000);
    System.out.println("Pressing the clear button");
    Jau.controlClick(hWnd, 0x51);   // clear button
    Jau.sleep(1000);

    System.out.println("---------------------------------------");
    System.out.println("Multiplying 5 and 7");
        // this calculation uses controlClick() to 'press' the calculator's buttons

    System.out.println("press '5'");
    Jau.controlClick(hWnd, 0x87);   // 0x87 is the '5' button on the calculator
    Jau.sleep(1000);

    System.out.println("press '*'");
    Jau.controlClick(hWnd, 0x5c);    // * button
    Jau.sleep(1000);

    System.out.println("press '7'");
    Jau.controlClick(hWnd, 0x89);    // 7 button
    Jau.sleep(1000);

    System.out.println("press '='");
    Jau.controlClick(hWnd, 0x79);    // = button
    Jau.sleep(1000);

    System.out.println("  Result: " + Jau.controlGetText(hWnd, 0x96));

    Jau.sleep(3000);
    Jau.winClose(hWnd);
  }  // end of main()

}  // end of UseCalc class
