
// UseNotepad.java
// Andrew Davison, ad@fivedots.coe.psu.ac.th, April 2014

/* Write some text into a new notepad file, and save it as
   foo.txt after deleting any previous version of that file.

   Deal with notepad's menu, and a secondary save windiow.

   Also messes around with text carat calculation by adjusting
   the caret coordinates mode.

   Access the text via Notepad's edit control (0x000F).
*/

import java.awt.*;
import java.io.*;
import com.sun.jna.platform.win32.WinDef.*;


public class UseNotepad
{
  public static void main (String args[])
  {
    HWND hWnd = Jau.run("notepad.exe");

    System.out.println("Caret Position = " + getCaretPos(hWnd, 0x000F));
        // 0x000F is the control ID of the edit control inside Notepad

    System.out.println("Screen Jau Caret Position = " + Jau.winGetCaretPos());

    Jau.winCaretCoordMode(Jau.CC_WINDOW);
    System.out.println("Window Jau Caret Position = " + Jau.winGetCaretPos());

    Jau.winCaretCoordMode(Jau.CC_CLIENT);
    System.out.println("1. Client Jau Caret Position = " + Jau.winGetCaretPos());

    // enter some text
    Jau.send(hWnd, "hello world\n");
    System.out.println("1. Window text: \"" + Jau.winGetText(hWnd) + "\"");

    Jau.sleep(1000);
    Jau.send(hWnd, "andrew{ENTER}"); 
    System.out.println("2. Window text: \"" + Jau.winGetText(hWnd) + "\"");

    System.out.println("\nCaret Position = " + getCaretPos(hWnd, 0x000F));
    System.out.println("2. Client Jau Caret Position = " + Jau.winGetCaretPos());

    // copy all the text
    Jau.send(hWnd, "^a");            // Ctrl+a
    Jau.send(hWnd, "^c");            // Ctrl+c
    Jau.sleep(500);
    System.out.println("\nClip board contents: \"" + Jau.clipGet() + "\"");

    deleteFile("foo.txt");
 
    // save using shortcut keys
    // Jau.send(hWnd, "!fa");            // alt + f + a == save as
        // http://shortcutkeys747.blogspot.com/2012/01/notepad-shortcut-keys.html#.UzQbOs6s_iw

    // save using the menu
    Jau.winMenuSelectItem(hWnd,  "&File", "Save &As...");

    // a "Save As" window will pop up and ask to save the changes
    Jau.winWaitActive("Save As");
    Jau.sleep(1000);
    Jau.send("foo.txt");   // assume foo.txt does not already exist
    Jau.sleep(1000);       // wait a bit
    Jau.send("{ENTER}");
    System.out.println("Saved foo.txt");

    Jau.sleep(3000);
    Jau.winClose(hWnd);
  }  // end of main()


  public static Point getCaretPos(HWND hWnd, int ctrlID)
  // return the caret's line and column positions
  {
    String result = Jau.controlCommand(hWnd, ctrlID, "GetCurrentLine", "");
    int lineNum = Integer.parseInt(result);
    result = Jau.controlCommand(hWnd, ctrlID, "GetCurrentCol", "");
    int colNum = Integer.parseInt(result);
    return new Point(lineNum, colNum);
  }  // end of getCaretPos()


  public static boolean deleteFile(String fnm)
  // try to delete the specified file
  {	
    try{
      if ((new File(fnm)).delete()) {
        System.out.println(fnm + " deleted");
        return true;
      }
    }
    catch(Exception e) {}
    System.out.println(fnm + " NOT deleted");
    return false;
  }  // end of deleteFile()

}  // end of UseNotepad class
