
// UseSketchup.java
// Andrew Davison, ad@fivedots.coe.psu.ac.th, April 2014

/*  Start sketchup, create an untitled window, and open the
    Ruby command console. Type in two ruby commands, reading back
    the text. Close sketchup.

   The control IDs were found using WinSpy++
   (http://www.catch22.net/software/winspy-17).
*/


import com.sun.jna.platform.win32.WinDef.*;


public class UseSketchup
{
  public static void main (String args[])
  {
    // start sketchup, waiting for its welcome window
    String sketchup = Jau.appsDir() + "\\SketchUp\\SketchUp 2013\\SketchUp.exe";
    HWND welcomeHandle = Jau.run(sketchup, "Welcome");

    if (welcomeHandle == null) {
      System.out.println("Sketchup welcome has not appeared");
      System.exit(1);
    }
    else
      System.out.println("Welcome window has appeared");

    Jau.sleep(3000);   // wait a bit before pressing button at bottom-right
    Jau.controlClick(welcomeHandle, 0x0001);  
         // click on the button to create an untitled new window

    HWND hWnd = Jau.winWaitActiveHandle("Untitled");
    System.out.println("Sketchup untitled window is active");
    System.out.println("Handle name: " + Jau.handleString(hWnd));

    // open the ruby console 
    HWND rubyHandle = startRubyConsole("Ruby Console");

    // enter commands into bottom field, read results from top field of console
    Jau.controlFocus(rubyHandle, 0x0A83);
    Jau.send("2 {+} 3{ENTER}");
    Jau.sleep(1000); 
    String[] lns = getDisplay(rubyHandle, 0x0A82);

    Jau.controlSetText(rubyHandle, 0x0A82, "");   // clear the display
    Jau.sleep(1000); 

    // enter another command, read results again
    Jau.controlFocus(rubyHandle, 0x0A83);
    Jau.send("6 {+} 7{ENTER}");
    Jau.sleep(1000);
    getDisplay(rubyHandle, 0x0A82);

    if (hWnd != null) {
      Jau.sleep(3000);
      Jau.winClose(hWnd);
    }
  }  // end of main()


  private static HWND startRubyConsole(String title)
  {
    System.out.println("Bring up \"" + title +"\"");
    Jau.send("{ALT down}wr{ALT up}");   // alt-w, alt-r
    Jau.sleep(1000);

    HWND hWnd = Jau.winWaitActiveHandle(title, 4);   // 4 sec wait
    if (hWnd == null) {
      System.out.println("\"" + title + "\" does not exist");
      System.exit(1);
    }
    else
      System.out.println("\"" + title + "\" created");
    Jau.sleep(1000);
    return hWnd;
  }  // end of startRubyConsole()



  private static String[] getDisplay(HWND rubyHandle, int ctrlID)
  // return the control's text as an array of lines
  {
    char[] display = new char[200];

    String displayText = Jau.controlGetText(rubyHandle, ctrlID);
    System.out.println("----------- Display -----------");
    System.out.println(displayText);
    System.out.println("-------------------------------");

    String[] lns = displayText.split("\\r?\\n");
    if (lns == null)
      System.out.println("No display lines read");
    else
      System.out.println("Display lines count: " + lns.length);

    return lns;
  }  // end of getDisplay()


}  // end of UseSketchup class
